/*
 * Copyright 2023 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.audit;

import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.Selector;
import dk.vajhoej.record.StructField;
import dk.vajhoej.record.SubType;

@Struct
public class AuditPacket {
	@StructField(n=0, type=FieldType.INT2)
	private int size;
	@StructField(n=1, type=FieldType.INT2)
    @Selector(subtypes={@SubType(value=1,type=AuditPacketUsername.class),
    					@SubType(value=2,type=AuditPacketSystem.class),
    					@SubType(value=3,type=AuditPacketTerminal.class),
    					@SubType(value=4,type=AuditPacketProcessId.class),
    					@SubType(value=5,type=AuditPacketProcessName.class),
    					@SubType(value=6,type=AuditPacketTimeStamp.class),
    					@SubType(value=7,type=AuditPacketRemoteSystem.class),
    					@SubType(value=8,type=AuditPacketRemoteUsername.class),
    					@SubType(value=9,type=AuditPacketImageName.class),
    					@SubType(value=10,type=AuditPacketFieldName.class),
    					@SubType(value=11,type=AuditPacketOriginalData.class),
    					@SubType(value=12,type=AuditPacketNewData.class),
    					@SubType(value=13,type=AuditPacketObjectName.class),
    					@SubType(value=14,type=AuditPacketObjectClass.class),
    					@SubType(value=15,type=AuditPacketIdName.class),
    					@SubType(value=16,type=AuditPacketIdNewName.class),
    					@SubType(value=17,type=AuditPacketIdValue.class),
    					@SubType(value=18,type=AuditPacketIdNewValue.class),
    					@SubType(value=19,type=AuditPacketIdAttributes.class),
    					@SubType(value=20,type=AuditPacketHolderName.class),
    					@SubType(value=21,type=AuditPacketPassword.class),
    					@SubType(value=22,type=AuditPacketSource.class),
    					@SubType(value=1000,type=AuditPacketDefault.class)})
	private int type;
	public int getSize() {
		return size;
	}
	public void setSize(int size) {
		this.size = size;
	}
	public int getType() {
		return type;
	}
	public void setType(int type) {
		this.type = type;
	}
	public String getKey() {
		throw new RuntimeException("Base type getKey should never be called");
	}
	public String getValue() {
		throw new RuntimeException("Base type getValue should never be called");
	}
	public String toString() {
		String key = getKey();
		String value = getValue();
		if(key != null) {
			if(value != null) {
				return key + "=\"" + value + "\"";
			} else {
				return key;
			}
		} else {
			return "";
		}
	}
}
