/*
 * Copyright 2023 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.audit;

import dk.vajhoej.record.InfoProvider;
import dk.vajhoej.record.LengthProvider2;

public class AuditPacketProvider implements InfoProvider {
	public int getLength(Object o, int n) {
		if(n == 2) {
			return ((AuditPacket)o).getSize() - 4;
		}
		return -1; // ignore
	}
	public int getMaxLength() {
		return 32767; // VMS max variable length record
	}
	public int getElements(Object o, int n) {
		return -1; // ignore
	}
	public LengthProvider2 getLengthProvider(Object o, int n) {
		return null; // ignore
	}
	public boolean hasConvertSelector() {
		return true;
	}
	public int convertSelector(Object o) {
		switch((int)(Integer)o) {
			case AuditPacketType.NSA$C_PKT_USERNAME: return 1; 
			case AuditPacketType.NSA$C_PKT_SYSTEM_NAME: return 2; 
			case AuditPacketType.NSA$C_PKT_TERMINAL: return 3; 
			case AuditPacketType.NSA$C_PKT_PROCESS_ID: return 4; 
			case AuditPacketType.NSA$C_PKT_PROCESS_NAME: return 5; 
			case AuditPacketType.NSA$C_PKT_TIME_STAMP: return 6; 
			case AuditPacketType.NSA$C_PKT_REMOTE_NODENAME: return 7; 
			case AuditPacketType.NSA$C_PKT_REMOTE_USERNAME: return 8; 
			case AuditPacketType.NSA$C_PKT_IMAGE_NAME: return 9;
			case AuditPacketType.NSA$C_PKT_FIELD_NAME: return 10; 
			case AuditPacketType.NSA$C_PKT_ORIGINAL_DATA: return 11;
			case AuditPacketType.NSA$C_PKT_NEW_DATA: return 12;
			case AuditPacketType.NSA$C_PKT_SENSITIVE_FIELD_NAME: return 10; 
			case AuditPacketType.NSA$C_PKT_SENSITIVE_ORIG_DATA: return 11;
			case AuditPacketType.NSA$C_PKT_SENSITIVE_NEW_DATA: return 12;
			case AuditPacketType.NSA$C_PKT_OBJECT_NAME: return 13;
			case AuditPacketType.NSA$C_PKT_OBJECT_CLASS: return 14;
			case AuditPacketType.NSA$C_PKT_ID_NAME: return 15;
			case AuditPacketType.NSA$C_PKT_ID_NEW_NAME: return 16;
			case AuditPacketType.NSA$C_PKT_ID_VALUE: return 17;
			case AuditPacketType.NSA$C_PKT_ID_NEW_VALUE: return 18;
			case AuditPacketType.NSA$C_PKT_ID_ATTRIBUTES: return 19;
			case AuditPacketType.NSA$C_PKT_HOLDER_NAME: return 20;
			case AuditPacketType.NSA$C_PKT_PASSWORD: return 21;
			case AuditPacketType.NSA$C_PKT_UAF_SOURCE: return 22;
			default: return 1000;
		}
	}
}
