/*
 * Copyright 2023 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.audit;

import dk.vajhoej.record.ArrayField;
import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;

@Struct
public class AuditRecord {
	@StructField(n=0, type=FieldType.STRUCT)
	private AuditHeader header;
	@ArrayField
	@StructField(n=1, type=FieldType.STRUCT)
	private AuditPacket[] packets;
	@StructField(n=2,type=FieldType.FIXSTR,length=-1)
	private String eol;
	public AuditRecord() {
		packets = new AuditPacket[0];
	}
	public AuditHeader getHeader() {
		return header;
	}
	public void setHeader(AuditHeader header) {
		this.header = header;
	}
	public AuditPacket[] getPackets() {
		return packets;
	}
	public void setPackets(AuditPacket[] packets) {
		this.packets = packets;
	}
	public String getEol() {
		return eol;
	}
	public void setEol(String eol) {
		this.eol = eol;
	}
	public String toString() {
		String res = AuditType.asString(header.getType());
		String subtyp = AuditSubType.asString(header.getType(), header.getSubType());
		if(subtyp != null) {
			res = res + " - " + subtyp;
		}
		res = res + " :";
		for(AuditPacket ap : packets) {
			String pkt = ap.toString();
			if(pkt.length() > 0) {
				res = res + " " + pkt;
			}
		}
		return res;
	}
}
