/*
 * Copyright 2023 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.audit;

public class AuditSubType extends AuditType {
    public static final int NSA$C_AUDIT_DISABLED = 1;
    public static final int NSA$C_AUDIT_ENABLED = 2;
    public static final int NSA$C_AUDIT_TERMINATE = 3;
    public static final int NSA$C_AUDIT_INITIATE = 4;
    public static final int NSA$C_SNAPSHOT_SAVE = 5;
    public static final int NSA$C_SNAPSHOT_ABORT = 6;
    public static final int NSA$C_SNAPSHOT_STARTUP = 7;
    public static final int NSA$C_SNAPSHOT_ACCESS = 8;
    public static final int NSA$C_AUDIT_STATE = 9;
    public static final int NSA$C_ALARM_STATE = 10;
    public static final int NSA$C_AUDIT_LOG_FINAL = 11;
    public static final int NSA$C_AUDIT_LOG_FIRST = 12;
    public static final int NSA$C_AUDIT_BAD_TCB_AUDIT = 13;
    public static final int NSA$C_BATCH = 1;
    public static final int NSA$C_DETACHED = 2;
    public static final int NSA$C_DIALUP = 3;
    public static final int NSA$C_LOCAL = 4;
    public static final int NSA$C_NETWORK = 5;
    public static final int NSA$C_REMOTE = 6;
    public static final int NSA$C_SUBPROCESS = 7;
    public static final int NSA$C_NETPROXY_ADD = 1;
    public static final int NSA$C_NETPROXY_DELETE = 2;
    public static final int NSA$C_NETPROXY_MODIFY = 3;
    public static final int NSA$C_NETPROXY_CREATE = 7;
    public static final int NSA$C_SYSUAF_ADD = 1;
    public static final int NSA$C_SYSUAF_COPY = 2;
    public static final int NSA$C_SYSUAF_DELETE = 3;
    public static final int NSA$C_SYSUAF_MODIFY = 4;
    public static final int NSA$C_SYSUAF_RENAME = 5;
    public static final int NSA$C_RDB_ADD_ID = 1;
    public static final int NSA$C_RDB_CREATE = 2;
    public static final int NSA$C_RDB_GRANT_ID = 3;
    public static final int NSA$C_RDB_MOD_HOLDER = 4;
    public static final int NSA$C_RDB_MOD_ID = 5;
    public static final int NSA$C_RDB_REM_ID = 6;
    public static final int NSA$C_RDB_REVOKE_ID = 7;
   	public static String asString(int typ, int subtyp) {
		switch(typ) {
			case NSA$C_MSG_AUDIT:
				switch(subtyp) {
					case NSA$C_AUDIT_ENABLED: return "Enabled";
					case NSA$C_AUDIT_DISABLED: return "Disabled";
					case NSA$C_AUDIT_INITIATE: return "Startup";
					case NSA$C_AUDIT_TERMINATE: return "Shutdown";
					default: return "Other";
				}
			case NSA$C_MSG_BREAKIN:
			case NSA$C_MSG_LOGFAIL:
    		case NSA$C_MSG_LOGIN: 
    		case NSA$C_MSG_LOGOUT:
				switch(subtyp) {
					case NSA$C_BATCH: return "Batch";
					case NSA$C_DETACHED: return "Detached";
					case NSA$C_LOCAL: return "Local";
					case NSA$C_NETWORK: return "Network";
					case NSA$C_REMOTE: return "Remote";
					case NSA$C_SUBPROCESS: return "Subprocess";
					default: return "Other";
				}
    		case NSA$C_MSG_NETPROXY:
				switch(subtyp) {
					case NSA$C_NETPROXY_ADD: return "Add";
					case NSA$C_NETPROXY_DELETE: return "Delete";
					case NSA$C_NETPROXY_MODIFY: return "Modify";
					case NSA$C_NETPROXY_CREATE: return "Create";
					default: return "Other";
				}
    		case NSA$C_MSG_SYSUAF:
				switch(subtyp) {
					case NSA$C_SYSUAF_ADD: return "Add";
					case NSA$C_SYSUAF_COPY: return "Copy";
					case NSA$C_SYSUAF_DELETE: return "Delete";
					case NSA$C_SYSUAF_MODIFY: return "Modify";
					case NSA$C_SYSUAF_RENAME: return "Rename";
					default: return "Other";
			}
    		case NSA$C_MSG_RIGHTSDB:
				switch(subtyp) {
					case NSA$C_RDB_ADD_ID: return "Add ID";
					case NSA$C_RDB_CREATE: return "Create";
					case NSA$C_RDB_GRANT_ID: return "Grant ID";
					case NSA$C_RDB_MOD_HOLDER: return "Modify holder";
					case NSA$C_RDB_MOD_ID: return "Modify ID";
					case NSA$C_RDB_REM_ID: return "Remove ID";
					case NSA$C_RDB_REVOKE_ID: return "Revoke ID";
					default: return "Other";
			}
			default: return null;
		}
	}
}
