/*
 * Copyright 2023 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.audit.db.struct;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;

import dk.vajhoej.vms.audit.AuditPacket;
import dk.vajhoej.vms.audit.AuditRecord;
import dk.vajhoej.vms.audit.AuditSubType;
import dk.vajhoej.vms.audit.AuditType;
import dk.vajhoej.vms.audit.Util;

public class AuditDbFactory {
	private static String findValue(AuditRecord ar, String key) {
		String res = null;
		for(AuditPacket ap : ar.getPackets()) {
			if(ap.getKey() != null) {
				if(ap.getKey().equals(key)) {
					res = ap.getValue();
				}
			}
		}
		return res;
	}
	public static AuditDbEvent convert(AuditRecord ar, AuditDbIdGen idgen) throws ParseException {
		AuditDbEvent res = null;
		int typ = ar.getHeader().getType();
		int subtyp = ar.getHeader().getSubType();
		switch(typ) {
			case AuditType.NSA$C_MSG_AUDIT:
			case AuditType.NSA$C_MSG_NETPROXY:
				res = new AuditDbEventLocal(idgen.getEventId(), AuditType.asString(typ), AuditSubType.asString(typ, subtyp), Util.s2t(findValue(ar, "TimeStamp")),
						                    findValue(ar, "PID"), findValue(ar, "Username"), findValue(ar, "System"));
				break;
			case AuditType.NSA$C_MSG_RIGHTSDB:
				res = new AuditDbEventLocalId(idgen.getEventId(), AuditType.asString(typ), AuditSubType.asString(typ, subtyp), Util.s2t(findValue(ar, "TimeStamp")),
	                                          findValue(ar, "PID"), findValue(ar, "Username"), findValue(ar, "System"),
	                                          findValue(ar, "IdName"), findValue(ar, "IdValue"));
				break;
			case AuditType.NSA$C_MSG_SYSUAF:
				int aeid = idgen.getEventId();
				List<AuditDbFieldUpdate> upd = new ArrayList<AuditDbFieldUpdate>();
				AuditPacket[] p = ar.getPackets();
				for(int i = 0; i < p.length - 2; i++) {
					if("FieldName".equals(p[i].getKey()) && "NewData".equals(p[i+1].getKey()) && "OriginalData".equals(p[i+2].getKey())) {
						upd.add(new AuditDbFieldUpdate(idgen.getUpdateId(), aeid, p[i].getValue(), p[i+2].getValue(), p[i+1].getValue()));
					}
				}
				res = new AuditDbEventLocalFieldUpdates(aeid, AuditType.asString(typ), AuditSubType.asString(typ, subtyp), Util.s2t(findValue(ar, "TimeStamp")),
						                                findValue(ar, "PID"), findValue(ar, "Username"), findValue(ar, "System"),
						                                findValue(ar, "Source"), upd);
				break;
			case AuditType.NSA$C_MSG_LOGFAIL:
			case AuditType.NSA$C_MSG_BREAKIN:
				res = new AuditDbEventLocalRemote(idgen.getEventId(), AuditType.asString(typ), AuditSubType.asString(typ, subtyp), Util.s2t(findValue(ar, "TimeStamp")),
						                          findValue(ar, "PID"), findValue(ar, "Username"), findValue(ar, "System"),
						                          findValue(ar, "RemoteUsername"), findValue(ar, "RemoteSystem"), findValue(ar, "Terminal"));
				break;
			default:
				System.out.printf("Unknown type: %s\n", ar);
				System.exit(0);
		}
		return res;
	}
}
