/*
 * Copyright 2023 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.audit.tools;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

import dk.vajhoej.record.RecordException;
import dk.vajhoej.vms.audit.AuditFile;
import dk.vajhoej.vms.audit.AuditRecord;
import dk.vajhoej.vms.audit.db.raw.AuditDbFactory;
import dk.vajhoej.vms.audit.db.raw.AuditDbIdGen;
import dk.vajhoej.vms.audit.db.raw.AuditDbIdGenSeq;
import dk.vajhoej.vms.audit.db.raw.AuditDbRecord;

public class ToDbRaw {
	public static void main(String[] args) throws IOException, RecordException {
	    try {
            if(args.length >= 2) {
                AuditFile af = new AuditFile(args[0]);
                Logger.getLogger("org.hibernate").setLevel(Level.OFF);
                EntityManagerFactory emf = Persistence.createEntityManagerFactory(args[1]);
                EntityManager em = emf.createEntityManager();
                AuditDbIdGen idgen = new AuditDbIdGenSeq(em);
                int n1 = 0;
                while(af.more()) {
                    AuditRecord ar = af.read();
                    AuditDbRecord adr = AuditDbFactory.convert(ar, idgen);
                    em.getTransaction().begin();
                    em.persist(adr);
                    em.getTransaction().commit();
                    n1++;
                }
                System.out.printf("%d AuditDbRecord inserted\n", n1);
                em.close();
                emf.close();
                af.close();
            } else {
                System.out.println("Usage: java -cp vmsaudit.jar:... dk.vajhoej.vms.audit.tools.ToDbRaw <audit-journal-file>  <persistence-unit-name>");
            }
	    } catch(Throwable ex) {
	        ex.printStackTrace();
	    }
	}
}
