/*
 * Copyright 2023 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.audit.tools;

import java.io.IOException;
import java.io.PrintWriter;

import dk.vajhoej.record.RecordException;
import dk.vajhoej.vms.audit.AuditFile;
import dk.vajhoej.vms.audit.AuditPacket;
import dk.vajhoej.vms.audit.AuditRecord;
import dk.vajhoej.vms.audit.AuditSubType;
import dk.vajhoej.vms.audit.AuditType;

public class ToJson {
	public static void main(String[] args) throws IOException, RecordException {
	    try {
            if(args.length >= 2) {
                AuditFile af = new AuditFile(args[0]);
                PrintWriter pw = new PrintWriter(args[1]);
                pw.println("{");
                pw.printf("    \"file\": \"%s\",\n", args[0]);
                pw.println("    \"records\": [");
                while(af.more()) {
                    AuditRecord ar = af.read();
                    int typ = ar.getHeader().getType();
                    int subtyp = ar.getHeader().getSubType();
                    pw.println("        {");
                    pw.printf("            \"type\": \"%s\",\n", AuditType.asString(typ));
                    pw.printf("            \"subtype\": \"%s\",\n", AuditSubType.asString(typ,  subtyp));
                    pw.println("            \"packets\": {");
                    StringBuilder sb = new StringBuilder();
                    for(AuditPacket ap : ar.getPackets()) {
                        if(ap.getKey() != null && ap.getValue() != null) {
                            sb.append(String.format("                \"%s\": \"%s\",\n", ap.getKey(), ap.getValue()));
                        }
                    }
                    pw.println(sb.substring(0, sb.length() - 2));
                    pw.println("            }");
                    if(af.more()) {
                        pw.println("        },");
                    } else {
                        pw.println("        }");
                    }
                }
                pw.println("    ]");
                pw.println("}");
                pw.close();
                af.close();
            } else {
                System.out.println("Usage: java -cp vmsaudit.jar dk.vajhoej.vms.audit.tools.ToJson <audit-journal-file> <output-file>");
            }
	    } catch(Throwable ex) {
	        ex.printStackTrace();
	    }
	}
}
